]> git.cameronkatri.com Git - mandoc.git/blobdiff - mandoc.h
Fix formatting of empty .Bl -inset item heads.
[mandoc.git] / mandoc.h
index 1f07296373cfdea4fc7f611b1a57422b18674dc9..1a0256eb3d88c145d19ebf2a4320bd7da879ad4b 100644 (file)
--- a/mandoc.h
+++ b/mandoc.h
@@ -1,6 +1,7 @@
-/*     $Id: mandoc.h,v 1.105 2012/11/16 22:21:05 schwarze Exp $ */
+/*     $Id: mandoc.h,v 1.132 2014/07/03 23:24:56 schwarze Exp $ */
 /*
  * Copyright (c) 2010, 2011 Kristaps Dzonsons <kristaps@bsd.lv>
 /*
  * Copyright (c) 2010, 2011 Kristaps Dzonsons <kristaps@bsd.lv>
+ * Copyright (c) 2010-2014 Ingo Schwarze <schwarze@openbsd.org>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -19,6 +20,7 @@
 
 #define ASCII_NBRSP     31  /* non-breaking space */
 #define        ASCII_HYPH       30  /* breakable hyphen */
 
 #define ASCII_NBRSP     31  /* non-breaking space */
 #define        ASCII_HYPH       30  /* breakable hyphen */
+#define        ASCII_BREAK      29  /* breakable zero-width space */
 
 /*
  * Status level.  This refers to both internal status (i.e., whilst
 
 /*
  * Status level.  This refers to both internal status (i.e., whilst
@@ -47,44 +49,50 @@ enum        mandocerr {
        MANDOCERR_WARNING, /* ===== start of warnings ===== */
 
        /* related to the prologue */
        MANDOCERR_WARNING, /* ===== start of warnings ===== */
 
        /* related to the prologue */
-       MANDOCERR_NOTITLE, /* no title in document */
-       MANDOCERR_UPPERCASE, /* document title should be all caps */
-       MANDOCERR_BADMSEC, /* unknown manual section */
-       MANDOCERR_BADVOLARCH, /* unknown manual volume or arch */
-       MANDOCERR_NODATE, /* date missing, using today's date */
-       MANDOCERR_BADDATE, /* cannot parse date, using it verbatim */
-       MANDOCERR_PROLOGOOO, /* prologue macros out of order */
-       MANDOCERR_PROLOGREP, /* duplicate prologue macro */
-       MANDOCERR_BADPROLOG, /* macro not allowed in prologue */
-       MANDOCERR_BADBODY, /* macro not allowed in body */
+       MANDOCERR_TH_MISSING, /* missing .TH macro, using "unknown 1" */
+       MANDOCERR_TITLE_CASE, /* lower case character in document title */
+       MANDOCERR_MSEC_BAD, /* unknown manual section: section */
+       MANDOCERR_ARCH_BAD, /* unknown manual volume or arch: volume */
+       MANDOCERR_DATE_MISSING, /* missing date, using today's date */
+       MANDOCERR_DATE_BAD, /* cannot parse date, using it verbatim: date */
+       MANDOCERR_PROLOG_ORDER, /* prologue macros out of order: macro */
+       MANDOCERR_PROLOG_REP, /* duplicate prologue macro: macro */
+       MANDOCERR_PROLOG_BAD, /* incomplete prologue, terminated by: macro */
+       MANDOCERR_PROLOG_ONLY, /* skipping prologue macro in body: macro */
 
        /* related to document structure */
 
        /* related to document structure */
-       MANDOCERR_SO, /* .so is fragile, better use ln(1) */
-       MANDOCERR_NAMESECFIRST, /* NAME section must come first */
-       MANDOCERR_BADNAMESEC, /* bad NAME section contents */
-       MANDOCERR_SECOOO, /* sections out of conventional order */
-       MANDOCERR_SECREP, /* duplicate section name */
-       MANDOCERR_SECMSEC, /* section not in conventional manual section */
+       MANDOCERR_SO, /* .so is fragile, better use ln(1): .so path */
+       MANDOCERR_DOC_EMPTY, /* no document body */
+       MANDOCERR_SEC_BEFORE, /* content before first section header: macro */
+       MANDOCERR_NAMESEC_FIRST, /* first section is not "NAME": title */
+       MANDOCERR_NAMESEC_BAD, /* bad NAME section contents: macro */
+       MANDOCERR_SEC_ORDER, /* sections out of conventional order: title */
+       MANDOCERR_SEC_REP, /* duplicate section title: title */
+       MANDOCERR_SEC_MSEC, /* unexpected section: title for ... only */
 
        /* related to macros and nesting */
 
        /* related to macros and nesting */
-       MANDOCERR_MACROOBS, /* skipping obsolete macro */
-       MANDOCERR_IGNPAR, /* skipping paragraph macro */
-       MANDOCERR_MOVEPAR, /* moving paragraph macro out of list */
-       MANDOCERR_IGNNS, /* skipping no-space macro */
-       MANDOCERR_SCOPENEST, /* blocks badly nested */
-       MANDOCERR_CHILD, /* child violates parent syntax */
-       MANDOCERR_NESTEDDISP, /* nested displays are not portable */
-       MANDOCERR_SCOPEREP, /* already in literal mode */
-       MANDOCERR_LINESCOPE, /* line scope broken */
-
-       /* related to missing macro arguments */
-       MANDOCERR_MACROEMPTY, /* skipping empty macro */
+       MANDOCERR_MACRO_OBS, /* obsolete macro: macro */
+       MANDOCERR_PAR_SKIP, /* skipping paragraph macro: macro ... */
+       MANDOCERR_PAR_MOVE, /* moving paragraph macro out of list: macro */
+       MANDOCERR_NS_SKIP, /* skipping no-space macro */
+       MANDOCERR_BLOCK_NEST, /* blocks badly nested: macro ... */
+       MANDOCERR_BD_NEST, /* nested displays are not portable: macro ... */
+       MANDOCERR_BL_MOVE, /* moving content out of list: macro */
+       MANDOCERR_VT_CHILD, /* .Vt block has child macro: macro */
+       MANDOCERR_FI_SKIP, /* fill mode already enabled, skipping .fi */
+       MANDOCERR_NF_SKIP, /* fill mode already disabled, skipping .nf */
+       MANDOCERR_LINESCOPE, /* line scope broken: macro breaks macro */
+
+       /* related to missing arguments */
+       MANDOCERR_REQ_EMPTY, /* skipping empty request: request */
+       MANDOCERR_COND_EMPTY, /* conditional request controls empty scope */
+       MANDOCERR_MACRO_EMPTY, /* skipping empty macro: macro */
        MANDOCERR_ARGCWARN, /* argument count wrong */
        MANDOCERR_DISPTYPE, /* missing display type */
        MANDOCERR_LISTFIRST, /* list type must come first */
        MANDOCERR_NOWIDTHARG, /* tag lists require a width argument */
        MANDOCERR_ARGCWARN, /* argument count wrong */
        MANDOCERR_DISPTYPE, /* missing display type */
        MANDOCERR_LISTFIRST, /* list type must come first */
        MANDOCERR_NOWIDTHARG, /* tag lists require a width argument */
+       MANDOCERR_IT_NOHEAD, /* missing head in list item: type */
        MANDOCERR_FONTTYPE, /* missing font type */
        MANDOCERR_FONTTYPE, /* missing font type */
-       MANDOCERR_WNOSCOPE, /* skipping end of block that is not open */
 
        /* related to bad macro arguments */
        MANDOCERR_IGNARGV, /* skipping argument */
 
        /* related to bad macro arguments */
        MANDOCERR_IGNARGV, /* skipping argument */
@@ -102,12 +110,9 @@ enum       mandocerr {
        MANDOCERR_BADTAB, /* tab in non-literal context */
        MANDOCERR_EOLNSPACE, /* end of line whitespace */
        MANDOCERR_BADCOMMENT, /* bad comment style */
        MANDOCERR_BADTAB, /* tab in non-literal context */
        MANDOCERR_EOLNSPACE, /* end of line whitespace */
        MANDOCERR_BADCOMMENT, /* bad comment style */
-       MANDOCERR_BADESCAPE, /* unknown escape sequence */
+       MANDOCERR_BADESCAPE, /* bad escape sequence */
        MANDOCERR_BADQUOTE, /* unterminated quoted string */
 
        MANDOCERR_BADQUOTE, /* unterminated quoted string */
 
-       /* related to equations */
-       MANDOCERR_EQNQUOTE, /* unexpected literal in equation */
-
        MANDOCERR_ERROR, /* ===== start of errors ===== */
 
        /* related to equations */
        MANDOCERR_ERROR, /* ===== start of errors ===== */
 
        /* related to equations */
@@ -131,38 +136,47 @@ enum      mandocerr {
        MANDOCERR_BADCHAR, /* skipping bad character */
        MANDOCERR_NAMESC, /* escaped character not allowed in a name */
        MANDOCERR_NONAME, /* manual name not yet set */
        MANDOCERR_BADCHAR, /* skipping bad character */
        MANDOCERR_NAMESC, /* escaped character not allowed in a name */
        MANDOCERR_NONAME, /* manual name not yet set */
-       MANDOCERR_NOTEXT, /* skipping text before the first section header */
+       MANDOCERR_NOTEXT, /* skipping text before first section header */
        MANDOCERR_MACRO, /* skipping unknown macro */
        MANDOCERR_REQUEST, /* NOT IMPLEMENTED: skipping request */
        MANDOCERR_ARGCOUNT, /* argument count wrong */
        MANDOCERR_MACRO, /* skipping unknown macro */
        MANDOCERR_REQUEST, /* NOT IMPLEMENTED: skipping request */
        MANDOCERR_ARGCOUNT, /* argument count wrong */
+       MANDOCERR_RS_SKIP, /* skipping invalid content in .Rs block: macro */
+       MANDOCERR_STRAYTA, /* skipping column outside column list */
        MANDOCERR_NOSCOPE, /* skipping end of block that is not open */
        MANDOCERR_SCOPEBROKEN, /* missing end of block */
        MANDOCERR_SCOPEEXIT, /* scope open on exit */
        MANDOCERR_UNAME, /* uname(3) system call failed */
        /* FIXME: merge following with MANDOCERR_ARGCOUNT */
        MANDOCERR_NOSCOPE, /* skipping end of block that is not open */
        MANDOCERR_SCOPEBROKEN, /* missing end of block */
        MANDOCERR_SCOPEEXIT, /* scope open on exit */
        MANDOCERR_UNAME, /* uname(3) system call failed */
        /* FIXME: merge following with MANDOCERR_ARGCOUNT */
-       MANDOCERR_NOARGS, /* macro requires line argument(s) */
        MANDOCERR_NOBODY, /* macro requires body argument(s) */
        MANDOCERR_NOARGV, /* macro requires argument(s) */
        MANDOCERR_NOBODY, /* macro requires body argument(s) */
        MANDOCERR_NOARGV, /* macro requires argument(s) */
+       MANDOCERR_NUMERIC, /* request requires a numeric argument */
        MANDOCERR_LISTTYPE, /* missing list type */
        MANDOCERR_ARGSLOST, /* line argument(s) will be lost */
        MANDOCERR_LISTTYPE, /* missing list type */
        MANDOCERR_ARGSLOST, /* line argument(s) will be lost */
-       MANDOCERR_BODYLOST, /* body argument(s) will be lost */
 
        MANDOCERR_FATAL, /* ===== start of fatal errors ===== */
 
 
        MANDOCERR_FATAL, /* ===== start of fatal errors ===== */
 
-       MANDOCERR_NOTMANUAL, /* manual isn't really a manual */
+       MANDOCERR_TOOLARGE, /* input too large */
+       MANDOCERR_NOTMANUAL, /* not a manual */
        MANDOCERR_COLUMNS, /* column syntax is inconsistent */
        MANDOCERR_BADDISP, /* NOT IMPLEMENTED: .Bd -file */
        MANDOCERR_SYNTARGVCOUNT, /* argument count wrong, violates syntax */
        MANDOCERR_SYNTCHILD, /* child violates parent syntax */
        MANDOCERR_SYNTARGCOUNT, /* argument count wrong, violates syntax */
        MANDOCERR_COLUMNS, /* column syntax is inconsistent */
        MANDOCERR_BADDISP, /* NOT IMPLEMENTED: .Bd -file */
        MANDOCERR_SYNTARGVCOUNT, /* argument count wrong, violates syntax */
        MANDOCERR_SYNTCHILD, /* child violates parent syntax */
        MANDOCERR_SYNTARGCOUNT, /* argument count wrong, violates syntax */
-       MANDOCERR_SOPATH, /* NOT IMPLEMENTED: .so with absolute path or ".." */
-       MANDOCERR_NODOCBODY, /* no document body */
+       MANDOCERR_SO_PATH, /* NOT IMPLEMENTED: .so with absolute path or ".." */
+       MANDOCERR_SO_FAIL, /* .so request failed */
        MANDOCERR_NODOCPROLOG, /* no document prologue */
        MANDOCERR_MEM, /* static buffer exhausted */
        MANDOCERR_NODOCPROLOG, /* no document prologue */
        MANDOCERR_MEM, /* static buffer exhausted */
+
+       /* ===== system errors ===== */
+
+       MANDOCERR_SYSOPEN, /* cannot open file */
+       MANDOCERR_SYSSTAT, /* cannot stat file */
+       MANDOCERR_SYSREAD, /* cannot read file */
+
        MANDOCERR_MAX
 };
 
        MANDOCERR_MAX
 };
 
-struct tbl {
+struct tbl_opts {
        char              tab; /* cell-separator */
        char              decimal; /* decimal point */
        int               linesize;
        char              tab; /* cell-separator */
        char              decimal; /* decimal point */
        int               linesize;
@@ -228,6 +242,7 @@ struct      tbl_row {
        struct tbl_row   *next;
        struct tbl_cell  *first;
        struct tbl_cell  *last;
        struct tbl_row   *next;
        struct tbl_cell  *first;
        struct tbl_cell  *last;
+       int               vert; /* trailing vertical line */
 };
 
 enum   tbl_datt {
 };
 
 enum   tbl_datt {
@@ -261,7 +276,7 @@ enum        tbl_spant {
  * A row of data in a table.
  */
 struct tbl_span {
  * A row of data in a table.
  */
 struct tbl_span {
-       struct tbl       *tbl;
+       struct tbl_opts  *opts;
        struct tbl_head  *head;
        struct tbl_row   *layout; /* layout row */
        struct tbl_dat   *first;
        struct tbl_head  *head;
        struct tbl_row   *layout; /* layout row */
        struct tbl_dat   *first;
@@ -350,7 +365,7 @@ struct      eqn_box {
 
 /*
  * An equation consists of a tree of expressions starting at a given
 
 /*
  * An equation consists of a tree of expressions starting at a given
- * line and position. 
+ * line and position.
  */
 struct eqn {
        char             *name; /* identifier (or NULL) */
  */
 struct eqn {
        char             *name; /* identifier (or NULL) */
@@ -360,15 +375,12 @@ struct    eqn {
 };
 
 /*
 };
 
 /*
- * The type of parse sequence.  This value is usually passed via the
- * mandoc(1) command line of -man and -mdoc.  It's almost exclusively
- * -mandoc but the others have been retained for compatibility.
+ * Parse options.
  */
  */
-enum   mparset {
-       MPARSE_AUTO, /* magically determine the document type */
-       MPARSE_MDOC, /* assume -mdoc */
-       MPARSE_MAN /* assume -man */
-};
+#define        MPARSE_MDOC     1  /* assume -mdoc */
+#define        MPARSE_MAN      2  /* assume -man */
+#define        MPARSE_SO       4  /* honour .so requests */
+#define        MPARSE_QUICK    8  /* abort the parse early */
 
 enum   mandoc_esc {
        ESCAPE_ERROR = 0, /* bail! unparsable escape */
 
 enum   mandoc_esc {
        ESCAPE_ERROR = 0, /* bail! unparsable escape */
@@ -377,6 +389,7 @@ enum        mandoc_esc {
        ESCAPE_FONT, /* a generic font mode */
        ESCAPE_FONTBOLD, /* bold font mode */
        ESCAPE_FONTITALIC, /* italic font mode */
        ESCAPE_FONT, /* a generic font mode */
        ESCAPE_FONTBOLD, /* bold font mode */
        ESCAPE_FONTITALIC, /* italic font mode */
+       ESCAPE_FONTBI, /* bold italic font mode */
        ESCAPE_FONTROMAN, /* roman font mode */
        ESCAPE_FONTPREV, /* previous font mode */
        ESCAPE_NUMBERED, /* a numbered glyph */
        ESCAPE_FONTROMAN, /* roman font mode */
        ESCAPE_FONTPREV, /* previous font mode */
        ESCAPE_NUMBERED, /* a numbered glyph */
@@ -395,30 +408,24 @@ struct    man;
 
 __BEGIN_DECLS
 
 
 __BEGIN_DECLS
 
-void            *mandoc_calloc(size_t, size_t);
 enum mandoc_esc          mandoc_escape(const char **, const char **, int *);
 enum mandoc_esc          mandoc_escape(const char **, const char **, int *);
-void            *mandoc_malloc(size_t);
-void            *mandoc_realloc(void *, size_t);
-char            *mandoc_strdup(const char *);
-char            *mandoc_strndup(const char *, size_t);
 struct mchars   *mchars_alloc(void);
 void             mchars_free(struct mchars *);
 struct mchars   *mchars_alloc(void);
 void             mchars_free(struct mchars *);
-char             mchars_num2char(const char *, size_t);
+char             mchars_num2char(const char *, size_t);
 int              mchars_num2uc(const char *, size_t);
 int              mchars_num2uc(const char *, size_t);
-int              mchars_spec2cp(const struct mchars *, 
+int              mchars_spec2cp(const struct mchars *,
                        const char *, size_t);
                        const char *, size_t);
-const char      *mchars_spec2str(const struct mchars *, 
+const char      *mchars_spec2str(const struct mchars *,
                        const char *, size_t, size_t *);
                        const char *, size_t, size_t *);
-struct mparse   *mparse_alloc(enum mparset, enum mandoclevel,
-                       mandocmsg, void *, char *);
+struct mparse   *mparse_alloc(int, enum mandoclevel, mandocmsg, char *);
 void             mparse_free(struct mparse *);
 void             mparse_keep(struct mparse *);
 enum mandoclevel  mparse_readfd(struct mparse *, int, const char *);
 enum mandoclevel  mparse_readmem(struct mparse *, const void *, size_t,
                        const char *);
 void             mparse_reset(struct mparse *);
 void             mparse_free(struct mparse *);
 void             mparse_keep(struct mparse *);
 enum mandoclevel  mparse_readfd(struct mparse *, int, const char *);
 enum mandoclevel  mparse_readmem(struct mparse *, const void *, size_t,
                        const char *);
 void             mparse_reset(struct mparse *);
-void             mparse_result(struct mparse *, 
-                       struct mdoc **, struct man **);
+void             mparse_result(struct mparse *,
+                       struct mdoc **, struct man **, char **);
 const char      *mparse_getkeep(const struct mparse *);
 const char      *mparse_strerror(enum mandocerr);
 const char      *mparse_strlevel(enum mandoclevel);
 const char      *mparse_getkeep(const struct mparse *);
 const char      *mparse_strerror(enum mandocerr);
 const char      *mparse_strlevel(enum mandoclevel);